# RIDGE

RIDGE is an algorithm for efficient grid-based evaluation of probability distributions.

A demonstration of how to use RIDGE can be found in [this jupyter notebook example](https://github.com/C-bowman/ridge/blob/main/examples/torus_example.ipynb).


## Installation

Ridge is available from [PyPI](https://pypi.org/project/pyridge/), 
so can be installed using [pip](https://pip.pypa.io/en/stable/) as follows:
```bash
pip install pyridge
```